@@ -4,13 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
-state $MONE = __PACKAGE__->new(-1, 0);
-state $ZERO = __PACKAGE__->new(+0, 0);
-state $ONE  = __PACKAGE__->new(+1, 0);
-
-state $I = __PACKAGE__->new(+0, 1);
+our $VERSION = '0.02';
 
 use overload
   '""' => \&stringify,
